#!/bin/bash

LOGFILE=jcasse_log
JOBFILE=jcasse.fio

WORKLOADS=("read" "randread" "write" "randwrite" "rw" "randrw")
#IOENGINES=("psync" "vsync" "psyncv" "mmap" "splice" "syslet-rw" "guasi")
IOENGINES=("sync" "libaio")
RANDOMMAP=("" "norandommap")
RANDOMGEN=("tausworthe" "lfsr")
IODIRECT=("direct=0" "direct=1")
IODEPTH=("iodepth=1" "iodepth=2")

echo Workloads that failed verification: > $LOGFILE

for workload in "${WORKLOADS[@]}"
do

    for ioengine in "${IOENGINES[@]}"
    do

        for randomgen in "${RANDOMGEN[@]}"
        do

            for randommap in "${RANDOMMAP[@]}"
            do

                for iodirect in "${IODIRECT[@]}"
                do

                    for iodepth in "${IODEPTH[@]}"
                    do

# Create job file
cat > $JOBFILE << End-of-job
[global]
filename=jcasse_data
size=1m
bs=4k
loops=2
randrepeat=1
verify=meta
verify_pattern=0xffffffffffffffff
verify_dump=0
continue_on_error=verify

[jcasse_job]
readwrite=${workload}
${iodirect}
${iodepth}
ioengine=${ioengine}
random_generator=${randomgen}
${randommap}
End-of-job

# Run fio
err="`./fio $JOBFILE | grep errors | cut -c24`"
err="`./fio $JOBFILE --verifyonly | grep errors | cut -c24`"

# Log workloads that failed verification
if [ $err != 0 ]
then
cat >> $LOGFILE << EOF
${workload} \
${iodirect} \
${iodepth} \
${ioengine} \
${randomgen} \
${randommap}
EOF
fi

                    done

                done

            done

        done

    done

done
